@@ -65,6 +65,9 @@ GtkUIManager     *ui = NULL;
 GtkWidget        *status_bar;
 GtkWidget        *balance_value_label;
 
+GtkAction *fullscreen_action;
+GtkAction *leave_fullscreen_action;
+
 guint32          seed;
 
 guint            x_spacing = 5;
@@ -83,6 +86,7 @@ gboolean show_toolbar = TRUE;
 gchar *game_variation = NULL;
 
 #define DEFAULT_VARIATION      "Vegas_Strip.rules"
+#define DEFAULT_THEME "bonded"
 
 void
 bj_make_window_title (gchar *game_name) 
@@ -159,6 +163,36 @@ bj_adjust_wager (gdouble offset)
         bj_set_wager (wager);
 }
 
+static void 
+set_fullscreen_actions (gboolean is_fullscreen)
+{
+        gtk_action_set_sensitive (leave_fullscreen_action, is_fullscreen);
+        gtk_action_set_visible (leave_fullscreen_action, is_fullscreen);
+
+        gtk_action_set_sensitive (fullscreen_action, !is_fullscreen);
+        gtk_action_set_visible (fullscreen_action, !is_fullscreen);
+}
+
+static void 
+fullscreen_cb (GtkAction *action)
+{
+	if (action == fullscreen_action) {
+		gtk_window_fullscreen (GTK_WINDOW (toplevel_window));
+	} else {
+		gtk_window_unfullscreen (GTK_WINDOW (toplevel_window));
+	}
+}
+
+/* Just in case something else takes us to/from fullscreen. */
+static void 
+window_state_cb (GtkWidget *widget, GdkEventWindowState *event)
+{
+	if (event->changed_mask & GDK_WINDOW_STATE_FULLSCREEN)
+        	set_fullscreen_actions (event->new_window_state &
+					GDK_WINDOW_STATE_FULLSCREEN);
+}
+
+
 static void
 bj_create_board (void)
 {
@@ -266,8 +300,12 @@ create_main_window (void)
                 "      <menuitem name='Quit' action='quit-game' />"
                 "      <placeholder name='GameMenuAdditions' />"
                 "    </menu>"
-                "    <menu name='SettingsMenu' action='settings-menu'>"
+		"    <menu name='ViewMenu' action='view-menu'>"
                 "      <menuitem name='Toolbar' action='show-toolbar'/>"
+		"      <menuitem action='Fullscreen'/>"
+		"      <menuitem action='LeaveFullscreen'/>"
+		"    </menu>"
+                "    <menu name='SettingsMenu' action='settings-menu'>"
                 "      <menuitem name='Preferences' action='show-preferences'/>"
                 "    </menu>"
                 "    <menu name='ControlMenu' action='control-menu'>"
@@ -296,11 +334,14 @@ create_main_window (void)
 
         static GtkActionEntry entries [] = {
                 { "game-menu", NULL, N_("_Game") },
-                { "new-game", GAMES_STOCK_NEW_GAME, NULL, NULL, NULL, G_CALLBACK (on_game_new_activate) },
-                { "restart-game", GAMES_STOCK_RESTART_GAME, NULL, NULL, NULL, G_CALLBACK (on_game_restart_activate) },
-                { "show-hint", GAMES_STOCK_HINT, NULL, NULL, NULL, G_CALLBACK (on_game_hint_activate) },
+		{ "view-menu", NULL, N_("_View") },
+                { "new-game", GAMES_STOCK_NEW_GAME, NULL, NULL, N_("Start a new game"), G_CALLBACK (on_game_new_activate) },
+                { "restart-game", GAMES_STOCK_RESTART_GAME, NULL, NULL, N_("Restart the current game"), G_CALLBACK (on_game_restart_activate) },
+                { "show-hint", GAMES_STOCK_HINT, NULL, NULL, N_("Show a hint"), G_CALLBACK (on_game_hint_activate) },
                 { "quit-game", GTK_STOCK_QUIT, NULL, NULL, NULL, G_CALLBACK (on_game_quit_activate) },
                 { "settings-menu", NULL, N_("_Settings") },
+		{ "Fullscreen", GAMES_STOCK_FULLSCREEN, NULL, NULL, NULL, G_CALLBACK (fullscreen_cb) },
+		{ "LeaveFullscreen", GAMES_STOCK_LEAVE_FULLSCREEN, NULL, NULL, NULL, G_CALLBACK (fullscreen_cb) },
                 { "show-preferences", GTK_STOCK_PREFERENCES, NULL, NULL, NULL, G_CALLBACK (on_preferences_activate) },
                 { "control-menu", NULL, N_("_Control") },
                 { "hand-deal", NULL, N_("D_eal"), NULL, N_("Deal a new hand"), G_CALLBACK (on_control_deal_activate) },
@@ -390,12 +431,21 @@ create_main_window (void)
 
         gtk_window_set_default_size (GTK_WINDOW (toplevel_window), width, height);
 
+	fullscreen_action = gtk_action_group_get_action (actions, "Fullscreen");
+	leave_fullscreen_action = gtk_action_group_get_action (actions,
+							       "LeaveFullscreen");
+
         bj_update_control_menu ();
 
+	set_fullscreen_actions (FALSE);
+
         g_signal_connect (toplevel_window, "delete_event", 
                           G_CALLBACK (bj_quit_app), NULL);
         g_signal_connect (toplevel_window, "configure_event",
                           G_CALLBACK (bj_event_configure), NULL);
+	g_signal_connect (G_OBJECT (toplevel_window), "window_state_event",
+			  G_CALLBACK (window_state_cb), NULL);
+
 }
 
 static void
@@ -504,7 +554,13 @@ bj_get_card_style ()
         lcard_style = gconf_client_get_string (bj_gconf_client (), 
                                                GCONF_KEY_CARD_STYLE,
                                                NULL);
-        return lcard_style;
+        /* Back compat */
+        if (g_str_has_suffix (lcard_style, ".svg"))
+          *g_strrstr (lcard_style, ".svg") = '\0';
+        else if (g_str_has_suffix (lcard_style, ".png"))
+          *g_strrstr (lcard_style, ".png") = '\0';
+
+        return lcard_style ? lcard_style : g_strdup (DEFAULT_THEME);
 }
 
 void
@@ -680,7 +736,7 @@ main (int argc, char *argv [])
         GError             *error      = NULL;
         char               *variation  = NULL;
         gboolean            retval;
-        static GOptionEntry entries [] = {
+        const GOptionEntry entries [] = {
                 { "variation", 0, 0, G_OPTION_ARG_STRING, &variation,
                   N_("Blackjack rule set to use"), NULL },
                 { NULL }
@@ -690,27 +746,44 @@ main (int argc, char *argv [])
         bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
         textdomain (GETTEXT_PACKAGE);
 
+#if defined(HAVE_GNOME) || defined(HAVE_RSVG_GNOMEVFS)
+  /* If we're going to use gnome-vfs, we need to init threads before
+   * calling any glib functions.
+   */
+  g_thread_init (NULL);
+#endif
+
         context = g_option_context_new (NULL);
-        g_option_context_set_ignore_unknown_options (context, TRUE);
-        g_option_context_add_main_entries (context, entries, NULL);
-        retval = g_option_context_parse (context, &argc, &argv, &error);
-        if (!variation)
-                variation = g_strdup (DEFAULT_VARIATION);
+#if GLIB_CHECK_VERSION (2, 12, 0)
+        g_option_context_set_translation_domain (context, GETTEXT_PACKAGE);
+#endif
+        g_option_context_add_main_entries (context, entries, GETTEXT_PACKAGE);
 
-        gtk_init_with_args (&argc, &argv, NULL, NULL, NULL, &error);
-
-        gconf_init (argc, argv, NULL);
-        gconf_client_add_dir (bj_gconf_client (), GCONF_KEY_DIR,
-                              GCONF_CLIENT_PRELOAD_NONE, NULL);
 
 #ifdef HAVE_GNOME
         GnomeProgram *program;
         program = gnome_program_init ("Blackjack", VERSION,
                                       LIBGNOMEUI_MODULE,
                                       argc, argv,
-                                      GNOME_PARAM_APP_DATADIR, DATADIR, NULL);
+                                      GNOME_PARAM_GOPTION_CONTEXT, context,
+                                      GNOME_PARAM_APP_DATADIR, DATADIR,
+                                      NULL);
+#else
+        g_option_context_add_group (context, gtk_get_option_group (TRUE));
+        retval = g_option_context_parse (context, &argc, &argv, &error);
+        if (!retval) {
+                g_print ("Error parsing arguments: %s\n", error->message);
+                g_error_free (error);
+                goto cleanup;
+        }
 #endif
 
+        if (!variation)
+                variation = g_strdup (DEFAULT_VARIATION);
+
+        gconf_client_add_dir (bj_gconf_client (), GCONF_KEY_DIR,
+                              GCONF_CLIENT_PRELOAD_NONE, NULL);
+
         gtk_widget_push_colormap (gdk_rgb_get_colormap ());
 
         gtk_window_set_default_icon_name ("gnome-blackjack");
@@ -721,6 +794,8 @@ main (int argc, char *argv [])
 
         main_prog (argc, argv);
 
+   cleanup:
+
         g_free (variation);
 
 #ifdef HAVE_GNOME
