@@ -3,7 +3,7 @@ __license__ = 'GNU General Public License Version 2'
 __copyright__ = 'Copyright 2005-2006  Robert Ancell'
 
 import os
-import gettext
+from gettext import gettext as _
 
 import gobject
 import gtk
@@ -12,7 +12,7 @@ import gtk.gdk
 
 import gtkui
 import glchess.ui
-        
+
 class GtkServerList:
     __gui = None
 
@@ -123,12 +123,12 @@ class GtkNewGameDialog:
             
         # Create model for game time
         defaultTime = glchess.config.get('new_game_dialog/move_time')
-        times = [(gettext.gettext('Unlimited'),       0),
-                 (gettext.gettext('One minute'),     60),
-                 (gettext.gettext('Five minutes'),  300),
-                 (gettext.gettext('30 minutes'),   1800),
-                 (gettext.gettext('One hour'),     3600),
-                 (gettext.gettext('Custom'),         -1)]
+        times = [(_('Unlimited'),       0),
+                 (_('One minute'),     60),
+                 (_('Five minutes'),  300),
+                 (_('30 minutes'),   1800),
+                 (_('One hour'),     3600),
+                 (_('Custom'),         -1)]
         timeModel = gtk.ListStore(str, int)
         activeIter = None
         for (name, time) in times:
@@ -148,9 +148,9 @@ class GtkNewGameDialog:
         widget.add_attribute(cell, 'text', 0)
 
         model = gtk.ListStore(str, int)
-        units = [(gettext.gettext('seconds'),  1),
-                 (gettext.gettext('minutes'), 60),
-                 (gettext.gettext('hours'), 3600)]
+        units = [(_('seconds'),  1),
+                 (_('minutes'), 60),
+                 (_('hours'), 3600)]
         for (name, multiplier) in units:
             iter = model.append()
             model.set(iter, 0, name, 1, multiplier)
@@ -167,9 +167,9 @@ class GtkNewGameDialog:
 
         # Create the model for difficulty options
         levelModel = gtk.ListStore(str, gtk.gdk.Pixbuf, str)
-        levels = [('easy',   gettext.gettext('Easy'),   'weather-few-clouds'),
-                  ('normal', gettext.gettext('Normal'), 'weather-overcast'),
-                  ('hard',   gettext.gettext('Hard'),   'weather-storm')]
+        levels = [('easy',   _('Easy'),   'weather-few-clouds'),
+                  ('normal', _('Normal'), 'weather-overcast'),
+                  ('hard',   _('Hard'),   'weather-storm')]
         iconTheme = gtk.icon_theme_get_default()
         for (key, label, iconName) in levels:
             try:
@@ -237,20 +237,20 @@ class GtkNewGameDialog:
             self.__gui.get_widget('game_name_entry').set_text(g.name)
             self.__customName = True
             if not self.__setCombo('white_type_combo', g.white.type):
-                errorText += gettext.gettext('Unable to find %s engine\n') % repr(g.white.type)
+                errorText += _('Unable to find %s engine\n') % repr(g.white.type)
             self.__setCombo('white_difficulty_combo', g.white.level)
             if not self.__setCombo('black_type_combo', g.black.type):
-                errorText += gettext.gettext('Unable to find %s engine\n') % repr(g.black.type)
+                errorText += _('Unable to find %s engine\n') % repr(g.black.type)
             self.__setCombo('black_difficulty_combo', g.black.level)
             # TODO: Others
             
             # Change title for loaded games
             if len(g.path) > 0:
-                self.__gui.get_widget('new_game_dialog').set_title(gettext.gettext('Configure loaded game (%i moves)') % len(g.moves))
+                self.__gui.get_widget('new_game_dialog').set_title(_('Configure loaded game (%i moves)') % len(g.moves))
 
         # Display warning if missing the AIs
         if len(errorText) > 0:
-            self.__gui.get_widget('info_title_label').set_markup('<big><b>%s</b></big>' % gettext.gettext('Game settings changed'))
+            self.__gui.get_widget('info_title_label').set_markup('<big><b>%s</b></big>' % _('Game settings changed'))
             self.__gui.get_widget('info_description_label').set_markup('<i>%s</i>' % errorText[:-1])
             self.__gui.get_widget('info_box').show()
 
@@ -310,7 +310,7 @@ class GtkNewGameDialog:
         else:
             whiteName = self.__getComboData(self.__gui.get_widget('white_type_combo'), 2)
             blackName = self.__getComboData(self.__gui.get_widget('black_type_combo'), 2)
-            format = gettext.gettext('%(white)s versus %(black)s')
+            format = _('%(white)s versus %(black)s')
             self.__gui.get_widget('game_name_entry').set_text(format % {'white': whiteName, 'black': blackName})
             
         # Disable difficulty for human players
@@ -333,13 +333,13 @@ class GtkNewGameDialog:
         # Get the players
         game.white.type  = self.__getComboData(self.__gui.get_widget('white_type_combo'), 0)
         if game.white.type == '':
-            game.white.name = gettext.gettext('White')
+            game.white.name = _('White')
         else:
             game.white.name = self.__getComboData(self.__gui.get_widget('white_type_combo'), 2)
         game.white.level = self.__getComboData(self.__gui.get_widget('white_difficulty_combo'), 0)
         game.black.type  = self.__getComboData(self.__gui.get_widget('black_type_combo'), 0)
         if game.black.type == '':
-            game.black.name = gettext.gettext('Black')
+            game.black.name = _('Black')
         else:
             game.black.name = self.__getComboData(self.__gui.get_widget('black_type_combo'), 2)
         game.black.level = self.__getComboData(self.__gui.get_widget('black_difficulty_combo'), 0)
@@ -401,264 +401,6 @@ class GtkNewGameDialog:
             self.__startGame()
         dialog.destroy()
 
-class GtkNetworkGameDialog(glchess.ui.NetworkController):
-    """
-    """
-    # The main UI and the ???
-    __mainUI = None
-    __gui = None
-
-    __customName = False
-    __checking = False
-    
-    def __init__(self, mainUI, feedback, aiModel):
-        """Constructor for a new game dialog.
-        
-        'mainUI' is the main UI.
-        'feedback' is the object to feedback events with.
-        'aiModel' is the AI models to use.
-        """
-        self.__mainUI = mainUI
-        self.feedback = feedback
-        
-        # Load the UI
-        self.__gui = gtkui.loadGladeFile('network_game.glade', 'network_game_dialog')
-        self.__gui.signal_autoconnect(self)
-        
-        # Make all the entries the same width
-        group = gtk.SizeGroup(gtk.SIZE_GROUP_HORIZONTAL)
-        for name in ['label1', 'label2', 'label3']:
-            widget = self.__gui.get_widget(name)
-            group.add_widget(widget)
-
-        # Make all the images the same width
-        group = gtk.SizeGroup(gtk.SIZE_GROUP_HORIZONTAL)
-        i = 1
-        while True:
-            widget = self.__gui.get_widget('image%i' % i)
-            if widget is None:
-                break
-            group.add_widget(widget)
-            i += 1
-
-        # Create the model for difficulty options
-        levelModel = gtk.ListStore(str, gtk.gdk.Pixbuf, str)
-        levels = [('easy',   gettext.gettext('Easy'),   'weather-few-clouds'),
-                  ('normal', gettext.gettext('Normal'), 'weather-overcast'),
-                  ('hard',   gettext.gettext('Hard'),   'weather-storm')]
-        iconTheme = gtk.icon_theme_get_default()
-        for (key, label, iconName) in levels:
-            try:
-                icon = iconTheme.load_icon(iconName, 24, gtk.ICON_LOOKUP_USE_BUILTIN)
-            except gobject.GError:
-                icon = None
-            iter = levelModel.append()
-            levelModel.set(iter, 0, key, 1, icon, 2, label)
-        
-        # Set the difficulty settings
-        widget = self.__gui.get_widget('difficulty_combo')
-        widget.set_model(levelModel)
-            
-        cell = gtk.CellRendererPixbuf()
-        widget.pack_start(cell, False)
-        widget.add_attribute(cell, 'pixbuf', 1)
-            
-        cell = gtk.CellRendererText()
-        widget.pack_start(cell, False)
-        widget.add_attribute(cell, 'text', 2)
-            
-        widget.set_active(1)
-        
-        # Make all the AI combo boxes use one list of AI types
-        widget = self.__gui.get_widget('player_type_combo')
-        widget.set_model(aiModel)
-            
-        cell = gtk.CellRendererPixbuf()
-        widget.pack_start(cell, False)
-        widget.add_attribute(cell, 'pixbuf', 1)
-            
-        cell = gtk.CellRendererText()
-        widget.pack_start(cell, False)
-        widget.add_attribute(cell, 'text', 2)
-
-        widget.set_active(0)
-
-        # Configure player
-        #try:
-        #    whiteType = glchess.config.get('new_game_dialog/white/type')
-        #    whiteLevel = glchess.config.get('new_game_dialog/white/difficulty')
-        #except glchess.config.Error:
-        #    pass
-        #else:
-        #    self.__setCombo('white_type_combo', whiteType)
-        #    self.__setCombo('white_difficulty_combo', whiteLevel)
-        #    self.__setCombo('black_type_combo', blackType)
-        #    self.__setCombo('black_difficulty_combo', blackLevel)
-        
-        # Create the model for the advertised games
-        self.gameModel = gtk.ListStore(gobject.TYPE_PYOBJECT, str, str, str)
-        view = self.__gui.get_widget('game_treeview')
-        view.set_model(self.gameModel)
-
-        cell = gtk.CellRendererText()
-        column = gtk.TreeViewColumn('Player', cell)
-        column.add_attribute(cell, 'text', 1)
-        view.append_column(column)
-
-        cell = gtk.CellRendererText()
-        column = gtk.TreeViewColumn('Rating', cell)
-        column.add_attribute(cell, 'text', 2)
-        view.append_column(column)
-
-        cell = gtk.CellRendererText()
-        column = gtk.TreeViewColumn('Variant', cell)
-        column.add_attribute(cell, 'text', 3)
-        view.append_column(column)
-
-        # Create styles for the buffer
-        buffer = self.__gui.get_widget('chat_textview').get_buffer()
-        buffer.create_tag('chat', family='Monospace')
-        #buffer.create_tag('output', family='Monospace', weight = pango.WEIGHT_BOLD)
-        #buffer.create_tag('move', family='Monospace', foreground = 'blue')
-        buffer.create_tag('info', family='Monospace', foreground = 'gray')
-        #buffer.create_tag('error', family='Monospace', foreground = 'red')
-
-        # Show the dialog
-        self.__testReady()
-        self.__gui.get_widget('network_game_dialog').show()
-
-    # Extended methods
-    
-    def addText(self, text, style):
-        """Called by glchess.ui.UIController"""
-        buffer = self.__gui.get_widget('chat_textview').get_buffer()
-        buffer.insert_with_tags_by_name(buffer.get_end_iter(), text, style)
-
-    def addAdvert(self, title, rating, variant, advert):
-        """Called by glchess.ui.UIController"""
-        iter = self.gameModel.append()
-        self.gameModel.set(iter, 0, advert, 1, title, 2, rating, 3, variant)
-        
-    def removeAdvert(self, advert):
-        """Called by glchess.ui.UIController"""
-        iter = self.gameModel.get_iter_first()
-        while iter:
-            if self.gameModel.get_value(iter, 0) is advert:
-                self.gameModel.remove(iter)
-                return
-            iter = self.gameModel.iter_next(iter)
-        print 'WARNING: Cannot find advert to remove'
-
-    def requestGame(self, gameName):
-        """Called by glchess.ui.UIController"""
-        # TEMP
-        self.feedback.acceptGame()
-
-    # Private methods
-    
-    def __setCombo(self, comboName, key):
-        widget = self.__gui.get_widget(comboName)
-        iter = self.__getIter(widget.get_model(), key)
-        if iter is not None:
-            widget.set_active_iter(iter)
-    
-    def __getIter(self, model, key, default = None):
-        """
-        """
-        iter = model.get_iter_first()
-        while iter:
-            if model.get_value(iter, 0) == key:
-                return iter
-
-            iter = model.iter_next(iter)
-        return default
-                
-    def __getComboData(self, comboBox, index):
-        """
-        """
-        model = comboBox.get_model()
-        iter = comboBox.get_active_iter()
-        if iter is None:
-            return None
-        
-        data = model.get(iter, index)
-        return data[0]
-
-    def __testReady(self):
-        if self.__checking:
-            return
-        self.__checking = True
-        ready = True
-           
-        # Disable difficulty for human players
-        playerType = self.__getComboData(self.__gui.get_widget('player_type_combo'), 0)
-        self.__gui.get_widget('difficulty_combo').set_sensitive(playerType != None)
-
-        # Get server/game
-        # FIXME
-        ready = False
-
-        # Can only click Connect if have enough information
-        self.__gui.get_widget('connect_button').set_sensitive(ready)
-        self.__checking = False
-        
-    def __startGame(self):
-        game = glchess.ui.Game()
-        game.name = self.__gui.get_widget('game_name_entry').get_text()
-        game.allowSpectators = True
-        
-        # Get the players
-        game.white.type  = self.__getComboData(self.__gui.get_widget('white_type_combo'), 0)
-        if game.white.type is '':
-            game.white.name = gettext.gettext('White')
-        else:
-            game.white.name = self.__getComboData(self.__gui.get_widget('white_type_combo'), 2)
-        game.white.level = self.__getComboData(self.__gui.get_widget('white_difficulty_combo'), 0)
-        game.black.type  = self.__getComboData(self.__gui.get_widget('black_type_combo'), 0)
-        if game.black.type == '':
-            game.black.name = gettext.gettext('Black')
-        else:
-            game.black.name = self.__getComboData(self.__gui.get_widget('black_type_combo'), 2)
-        game.black.level = self.__getComboData(self.__gui.get_widget('black_difficulty_combo'), 0)
-
-        game.duration = self.__getComboData(self.__gui.get_widget('time_combo'), 1)
-        if game.duration < 0:
-            multplier = self.__getComboData(self.__gui.get_widget('custom_time_units_combo'), 1)
-            game.duration = self.__getComboData(self.__gui.get_widget('custom_time_spin'), 1) * multiplier
-            
-        # Save properties
-        glchess.config.set('new_game_dialog/white/type', game.white.type)
-        glchess.config.set('new_game_dialog/white/difficulty', game.white.level)
-        glchess.config.set('new_game_dialog/black/type', game.black.type)
-        glchess.config.set('new_game_dialog/black/difficulty', game.black.level)
-
-        # Inform the child class
-        self.__mainUI.feedback.onGameStart(game)
-        
-    # Gtk+ signal handlers
-    
-    def _on_game_name_edited(self, widget):
-        """Gtk+ callback"""
-        if self.__checking:
-            return
-        self.__customName = len(widget.get_text()) != 0
-
-    def _on_properties_changed(self, widget, *data):
-        """Gtk+ callback"""
-        self.__testReady()
-        
-    def _on_chat_entry_activate(self, widget):
-        """Gtk+ callback"""
-        text = widget.get_text()
-        widget.set_text('')
-        self.feedback.sendCommand(text)
-
-    def _on_response(self, widget, response_id):
-        """Gtk+ callback"""
-        if response_id == gtk.RESPONSE_OK:
-            self.__startGame()
-        self.__gui.get_widget('new_game_dialog').destroy()
-
 class GtkLoadGameDialog:
     """
     """    
@@ -731,7 +473,7 @@ class GtkLoadGameDialog:
             if error is not None:
                 self.firstExpose = True
                 self.__gui.get_widget('error_box').show()
-                self.__gui.get_widget('error_title_label').set_markup('<big><b>%s</b></big>' % gettext.gettext('Unabled to load game'))
+                self.__gui.get_widget('error_title_label').set_markup('<big><b>%s</b></big>' % _('Unabled to load game'))
                 self.__gui.get_widget('error_description_label').set_markup('<i>%s</i>' % error)
                 return
 
@@ -878,7 +620,7 @@ class GtkSaveGameDialog:
             # Append .pgn to the end if not provided
             fname = chooser.get_filename()
             if fname is None:
-                self.__setError(gettext.gettext('Please enter a file name'), '')
+                self.__setError(_('Please enter a file name'), '')
                 return
             if fname[-4:].lower() != '.pgn':
                 fname += '.pgn'
@@ -888,7 +630,7 @@ class GtkSaveGameDialog:
         
             error = self.__mainUI._saveView(self.__view, fname)
             if error is not None:
-                self.__setError(gettext.gettext('Unabled to save game'), error)
+                self.__setError(_('Unabled to save game'), error)
                 return
         else:
             self.__mainUI._saveView(self.__view, None)
