@@ -39,20 +39,20 @@ except:
 def inactivate_new_game_etc (fun):
     def _ (ui, *args, **kwargs):
         paths = [
-            '/MenuBar/File/New',
-            #'/MenuBar/File/Open',
-            #'/MenuBar/File/ByHand',
-            '/MenuBar/File/Print',
+            '/MenuBar/Game/New',
+            #'/MenuBar/Game/Open',
+            #'/MenuBar/Game/ByHand',
+            '/MenuBar/Game/Print',
             '/MenuBar/Edit/Undo',
             '/MenuBar/Edit/Redo',
             '/MenuBar/Edit/Clear',
             '/MenuBar/Edit/ClearNotes',
-            '/MenuBar/Game/ShowPossible',
-            '/MenuBar/Game/AutofillCurrentSquare',
-            '/MenuBar/Game/Autofill',
-            '/MenuBar/Game/AlwaysShowPossible',
-            '/MenuBar/Game/ShowImpossibleImplications',
-            '/MenuBar/Game/Tracker',
+            '/MenuBar/Tools/ShowPossible',
+            '/MenuBar/Tools/AutofillCurrentSquare',
+            '/MenuBar/Tools/Autofill',
+            '/MenuBar/Tools/AlwaysShowPossible',
+            '/MenuBar/Tools/ShowImpossibleImplications',
+            '/MenuBar/Tools/Tracker',
             '/MenuBar/Game/PuzzleInfo',
             '/MenuBar/Game/HighScores',
             ]
@@ -72,8 +72,11 @@ def inactivate_new_game_etc (fun):
 class UI (gconf_wrapper.GConfWrapper):
     ui='''<ui>
     <menubar name="MenuBar">
-      <menu name="File" action="File">
+      <menu name="Game" action="Game">
         <menuitem action="New"/>
+        <separator/>
+        <menuitem action="PuzzleInfo"/>
+        <menuitem action="HighScores"/>
         <!--<menuitem action="Open"/>-->
         <!--<menuitem action="ByHand"/>-->
         <separator/>
@@ -81,10 +84,6 @@ class UI (gconf_wrapper.GConfWrapper):
         <menuitem action="PrintMany"/>
         <separator/>
         <!--<menuitem action="Save"/>-->
-        <separator/>
-        <menuitem action="Generator"/>
-        <menuitem action="BackgroundGenerator"/>
-        <separator/>
         <menuitem action="Close"/>
         <!--<menuitem action="Quit"/>-->
       </menu>
@@ -99,23 +98,22 @@ class UI (gconf_wrapper.GConfWrapper):
         <menuitem action="FullScreen"/>
         <separator/>
         <menuitem action="ToggleToolbar"/>
-        <menuitem action="ToggleBackground"/>
         <menuitem action="ToggleHighlight"/>        
       </menu>
-      <menu action="Game">
+      <menu action="Tools">
          <menuitem action="ShowPossible"/>
           <menuitem action="AutofillCurrentSquare"/>
           <menuitem action="Autofill"/>
           <separator/>
           <menuitem action="AlwaysShowPossible"/>
           <menuitem action="ShowImpossibleImplications"/>
+
+        <separator/>
+        <menuitem action="Generator"/>
+        <menuitem action="BackgroundGenerator"/>
         <separator/>
         <menuitem action="Tracker"/>
-        <separator/>
-        <menuitem action="PuzzleInfo"/>
-        <separator/>
-        <menuitem action="HighScores"/>
-       </menu>
+        </menu>
        <menu action="Help">
          <menuitem action="ShowHelp"/>
          <menuitem action="About"/>
@@ -152,6 +150,7 @@ class UI (gconf_wrapper.GConfWrapper):
                      'player':os.environ.get('USERNAME',''),
                      'difficulty':0.0,
                      'minimum_number_of_new_puzzles':MIN_NEW_PUZZLES,
+                     'highlight':0,
                      'bg_black':1,
                      'bg_custom_color':'',
                      'show_tracker':False,
@@ -162,6 +161,7 @@ class UI (gconf_wrapper.GConfWrapper):
 
     @simple_debug
     def __init__ (self):
+        gtk.window_set_default_icon_name('gnome-sudoku')
         self.w = gtk.Window()
         self.timer = ActiveTimer(self.w)
         self.won = False
@@ -173,11 +173,9 @@ class UI (gconf_wrapper.GConfWrapper):
 
         self.cleared = [] # used for Undo memory
         self.cleared_notes = [] # used for Undo memory
-        gnome.program_init('gnome-sudoku',VERSION,
-                           properties={gnome.PARAM_APP_DATADIR:APP_DATA_DIR}
-                           )
+        gnome.program_init('gnome-sudoku',VERSION, properties={gnome.PARAM_APP_DATADIR:APP_DATA_DIR})
         self.w.set_default_size(self.gconf['width'], self.gconf['height'])
-        self.w.set_title(APPNAME);
+        self.w.set_title(APPNAME_SHORT)
         self.w.connect('configure-event',self.resize_cb)
         self.w.connect('delete-event',self.quit_cb)
         self.vb = gtk.VBox()
@@ -193,7 +191,7 @@ class UI (gconf_wrapper.GConfWrapper):
         self.gsd.connect('puzzle-finished',self.you_win_callback)
         self.main_actions = gtk.ActionGroup('MainActions')        
         self.main_actions.add_actions([
-            ('File',None,_('_File')),
+            ('Game',None,_('_Game')),
             ('New',gtk.STOCK_NEW,None,
              '<Control>n',_('New game'),self.new_cb),
             ('Print',gtk.STOCK_PRINT,None,
@@ -203,7 +201,7 @@ class UI (gconf_wrapper.GConfWrapper):
             #('Quit',gtk.STOCK_QUIT,None,'<Control>q',
             # 'Quit Sudoku game',self.quit_cb),
             ('Close',gtk.STOCK_CLOSE,None,'<Control>w',
-             _('Close Sudoku (save game for later)'),self.quit_cb),
+             _('Close Sudoku'),self.quit_cb),
             #('Save',gtk.STOCK_SAVE,_('_Save'),
             # '<Control>s','Save game to play later.',
             # self.save_game),
@@ -213,10 +211,10 @@ class UI (gconf_wrapper.GConfWrapper):
             #('Open',gtk.STOCK_OPEN,_('_Resume old game'),
             # '<Control>r',_('Resume a previous saved game.'),
             # self.open_game),
-            ('Game',None,_('_Game')),
+            ('Tools',None,_('_Tools')),
             ('View',None,_('_View')),
             ('ShowPossible',gtk.STOCK_DIALOG_INFO,_('_Hint'),
-             '<Control>i',
+             '<Control>h',
              _('Show which numbers could go in the current square.'),
              self.show_hint_cb),
             ('AutofillCurrentSquare',gtk.STOCK_APPLY,_('_Fill'),'<Control>f',
@@ -263,15 +261,7 @@ class UI (gconf_wrapper.GConfWrapper):
              '<Control>T',
              _('Mark new additions in a separate color so you can keep track of them.'),
              self.tracker_toggle_cb,False),
-            #('ZoomOnResize',None,_('_Adjust size of grid when resizing window'),
-            # None,_('Automatically change the size of numbers and squares to fit the window.'),
-            # ),
             ('ToggleToolbar',None,_('Show _Toolbar'),None,None,self.toggle_toolbar_cb,True),
-            #('ToggleNotes',None,_('Show _Notes'),'<Control>O',
-            # _('Include room for notes at the top and bottom of squares.'),self.toggle_notes_cb),
-            ('ToggleBackground',None,_('_Black background'),
-             None,_("Background of game is black; otherwise, the background will follow your theme colors."),
-             self.toggle_background_cb,True),
             ('ToggleHighlight',gtk.STOCK_SELECT_COLOR,_('_Highlighter'),
              None,_('Highlight the current row, column and box'),self.toggle_highlight_cb,False),
             ('BackgroundGenerator',None,_('Generate new puzzles _while you play'),
@@ -368,8 +358,8 @@ class UI (gconf_wrapper.GConfWrapper):
               self.main_actions.get_action('BackgroundGenerator')),
              ('show_toolbar',
               self.main_actions.get_action('ToggleToolbar')),
-             ('bg_black',
-              self.main_actions.get_action('ToggleBackground')),
+             ('highlight',
+              self.main_actions.get_action('ToggleHighlight')),
              ('show_tracker',
               self.main_actions.get_action('Tracker')),
              ])
@@ -410,8 +400,6 @@ class UI (gconf_wrapper.GConfWrapper):
             gobject.timeout_add(1000,lambda *args: self.start_worker_thread() and True)
         self.gsd.show()
         
-        icon = gtk.gdk.pixbuf_new_from_file(os.path.join(ICON_DIR,'sudoku.png'))
-        self.w.set_icon(icon)
         self.w.show()
 
     @simple_debug
@@ -743,13 +731,6 @@ class UI (gconf_wrapper.GConfWrapper):
                             tot_string)
         return True
 
-    @simple_debug
-    def toggle_background_cb (self, widg):
-        if widg.get_active():
-            self.gsd.set_bg_color('black')
-        else:
-            self.gsd.set_bg_color(None)
-
     def toggle_highlight_cb (self, widg):
         if widg.get_active():
             self.gsd.toggle_highlight(True)
@@ -814,9 +795,8 @@ class UI (gconf_wrapper.GConfWrapper):
         about.set_comments(DESCRIPTION)
         about.set_authors(AUTHORS)
         about.set_website("http://www.gnome.org/projects/gnome-games/")
-        about.set_logo_icon_name("sudoku")
+        about.set_logo_icon_name("gnome-sudoku")
         about.set_translator_credits(_("translator-credits"))
-        about.set_icon_from_file(ICON_DIR + "/sudoku.png")
         about.connect("response", lambda d, r: d.destroy())
         about.show()
 
@@ -826,7 +806,8 @@ class UI (gconf_wrapper.GConfWrapper):
         try:
             gnome.help_display('gnome-sudoku')
         except gobject.GError, e:
-            print 'Unable to display help: %s' % str(e)
+            # FIXME: This should create a pop-up dialog
+            print _('Unable to display help: %s') % str(e)
 
     @simple_debug
     def print_game (self, *args):
