@@ -20,8 +20,8 @@
 
 #include <config.h>
 #include "tetris.h"
-#include <libgnomeui/gnome-window-icon.h>
 #include "games-scores.h"
+#include "games-sound.h"
 
 int
 main(int argc, char *argv[])
@@ -31,30 +31,39 @@ main(int argc, char *argv[])
 	bindtextdomain(GETTEXT_PACKAGE, GNOMELOCALEDIR);
         bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");	
 	textdomain(GETTEXT_PACKAGE);
-	
+
 	int cmdlineLevel = 0;
 
-	poptOption options[] = 
+	const GOptionEntry options[] = 
 	{
-		{"level", 'l', POPT_ARG_INT, &cmdlineLevel, 0, N_("Set starting level (1 or greater)"), N_("LEVEL")},
-		{0, '\0', 0, 0, 0}
+		{"level", 'l', 0, G_OPTION_ARG_INT, &cmdlineLevel, N_("Set starting level (1 or greater)"), N_("LEVEL")},
+		{NULL}
 	};
 
-	gnome_program_init ("gnometris", VERSION,
-			    LIBGNOMEUI_MODULE,
-			    argc, argv,
-			    GNOME_PARAM_POPT_TABLE, options,
-			    GNOME_PARAM_APP_DATADIR, DATADIR, NULL);
-	
-	gnome_window_icon_set_default_from_file (GNOME_ICONDIR"/gnome-gtetris.png");
+	g_thread_init (NULL);
 
-	Tetris * t = new Tetris(cmdlineLevel);
+	GOptionContext *context = g_option_context_new ("");
+
+	g_option_context_add_main_entries (context, options, GETTEXT_PACKAGE);
+	g_option_context_add_group (context, games_sound_get_option_group ());
+
+	GnomeProgram *program = gnome_program_init ("gnometris", VERSION,
+						    LIBGNOMEUI_MODULE,
+						    argc, argv,
+						    GNOME_PARAM_GOPTION_CONTEXT, context,
+						    GNOME_PARAM_APP_DATADIR, DATADIR,
+						    NULL);
+
+	gtk_window_set_default_icon_name ("gnome-gnometris");
+
+	Tetris *t = new Tetris(cmdlineLevel);
 
 	gtk_main();
 
-	delete t;
-
 	gnome_accelerators_sync();
-	
+
+	delete t;
+	g_object_unref (program);
+
 	return 0;
 }
