@@ -210,7 +210,7 @@ show_scores (gint pos, gboolean endofgame)
     if (scoresdialog != NULL) {
       gtk_window_present (GTK_WINDOW (scoresdialog));
     } else {
-      scoresdialog = games_scores_dialog_new (highscores, _("Mines Scores"));
+      scoresdialog = games_scores_dialog_new (GTK_WINDOW (window), highscores, _("Mines Scores"));
       games_scores_dialog_set_category_description (GAMES_SCORES_DIALOG
 						    (scoresdialog),
 						    _("Size:"));
@@ -334,7 +334,7 @@ hint_callback (void)
 static void
 pause_callback (GtkWidget * widget, GdkEventFocus * event, gpointer data)
 {
-  if ((GAMES_CLOCK (clk)->timer_id != -1)
+  if ((GAMES_CLOCK (clk)->timer_id != 0)
       && (!disable_hiding)) {
     gtk_widget_hide (mfield_container);
     gtk_widget_show (resume_container);
@@ -464,11 +464,11 @@ about_callback (void)
 			   "Clear mines from a board using hints from "
 			   "squares you have already uncovered."),
 			 "copyright",
-			 "Copyright \xc2\xa9 1997-2006 Free Software Foundation, Inc.",
+			 "Copyright \xc2\xa9 1997-2007 Free Software Foundation, Inc.",
 			 "license", license, "authors", authors, "artists",
 			 artists, "documenters", documenters,
 			 "translator_credits", _("translator-credits"),
-			 "logo-icon-name", "gnome-gnomine", "website",
+			 "logo-icon-name", "gnome-mines", "website",
 			 "http://www.gnome.org/projects/gnome-games/",
 			 "wrap-license", TRUE, NULL);
   g_free (license);
@@ -625,14 +625,16 @@ fullscreen_callback (GtkAction * action)
     gtk_window_unfullscreen (GTK_WINDOW (window));
 }
 
-static void
+static gboolean
 window_state_callback (GtkWidget * widget, GdkEventWindowState * event)
 {
   if (!(event->changed_mask & GDK_WINDOW_STATE_FULLSCREEN))
-    return;
+    return FALSE;
 
   set_fullscreen_actions (event->
 			  new_window_state & GDK_WINDOW_STATE_FULLSCREEN);
+    
+  return FALSE;
 }
 
 static void
@@ -1005,7 +1007,7 @@ main (int argc, char *argv[])
   gconf_client_notify_add (conf_client, KEY_DIR,
 			   gconf_key_change_cb, NULL, NULL, NULL);
 
-  gtk_window_set_default_icon_name ("gnome-gnomine");
+  gtk_window_set_default_icon_name ("gnome-mines");
   client = gnome_master_client ();
   g_signal_connect (G_OBJECT (client), "save_yourself",
 		    G_CALLBACK (save_state), argv[0]);
